@@ -1,14 +1,20 @@
 """ Entry point to trigger webhook(s). """
+import sys
 import argparse
+
 from discord_webhook import DiscordWebhook
 
 
-def main():
+def main() -> bool:
     parser = argparse.ArgumentParser(
         prog="discord_webhook", description="Trigger discord webhook(s)."
     )
     parser.add_argument(
-        "-u", "--url", required=True, nargs="+", help="Webhook(s) url(s)",
+        "-u",
+        "--url",
+        required=True,
+        nargs="+",
+        help="Webhook(s) url(s)",
     )
     parser.add_argument("-c", "--content", required=True, help="Message content")
     parser.add_argument(
@@ -24,8 +30,8 @@ def main():
         username=args.username,
         avatar_url=args.avatar_url,
     )
-    webhook.execute()
+    return webhook.execute() is not None
 
 
 if __name__ == "__main__":
-    main()
+    sys.exit(main())
